@@ -33,9 +33,10 @@
 #  define KICONTHEMES_DEPRECATED_NO_EXPORT KICONTHEMES_NO_EXPORT KICONTHEMES_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KICONTHEMES_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KICONTHEMES_NO_DEPRECATED
+#    define KICONTHEMES_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
